@@ -1,5 +1,5 @@
 #ifndef lint
-static char *RCSid() { return RCSid("$Id: internal.c,v 1.40.2.1 2007/06/19 21:15:12 sfeam Exp $"); }
+static char *RCSid() { return RCSid("$Id: internal.c,v 1.40.2.4 2008/09/25 19:50:57 sfeam Exp $"); }
 #endif
 
 /* GNUPLOT - internal.c */
@@ -40,6 +40,9 @@ static char *RCSid() { return RCSid("$Id: internal.c,v 1.40.2.1 2007/06/19 21:15
 #include "stdfn.h"
 #include "alloc.h"
 #include "util.h"		/* for int_error() */
+#ifdef GP_STRING_VARS
+# include "gp_time.h"           /* for str(p|f)time */
+#endif
 #include "command.h"            /* for do_system_func */
 
 #include <math.h>
@@ -1154,12 +1157,11 @@ f_words(union argument *arg)
  * go wrong if the user mis-matches arguments and format strings
  * in the call to sprintf, but I hope none will do worse than
  * result in a garbage output string.
- * FIXME: 10 is a purely arbitrary upper limit on args
  */
 void
 f_sprintf(union argument *arg)
 {
-    struct value a[10];
+    struct value a[10], *args;
     struct value num_params;
     struct value result;
     char *buffer;
@@ -1175,21 +1177,26 @@ f_sprintf(union argument *arg)
     /* Retrieve number of parameters from top of stack */
     pop(&num_params);
     nargs = num_params.v.int_val;
+    if (nargs > 10) {	/* Fall back to slow but sure allocation */
+	args = gp_alloc(sizeof(struct value)*nargs, "sprintf args");
+    } else
+	args = a;
+
     for (i=0; i<nargs; i++)
-	pop(&a[i]);  /* pop next argument */
+	pop(&args[i]);  /* pop next argument */
 
     /* Make sure we got a format string of some sort */
-    if (a[nargs-1].type != STRING)
+    if (args[nargs-1].type != STRING)
 	int_error(NO_CARET,"First parameter to sprintf must be a format string");
 
     /* Allocate space for the output string. If this isn't */
     /* long enough we can reallocate a larger space later. */
-    bufsize = 80 + strlen(a[nargs-1].v.string_val);
+    bufsize = 80 + strlen(args[nargs-1].v.string_val);
     buffer = gp_alloc(bufsize, "f_sprintf");
 
     /* Copy leading fragment of format into output buffer */
     outpos = buffer;
-    next_start  = a[nargs-1].v.string_val;
+    next_start  = args[nargs-1].v.string_val;
     next_length = strcspn(next_start,"%");
     strncpy(outpos, next_start, next_length);
 
@@ -1203,7 +1210,7 @@ f_sprintf(union argument *arg)
 
     /* Each time we start this loop we are pointing to a % character */
     while (remaining-->0 && next_start[0] && next_start[1]) {
-	struct value *next_param = &a[remaining];
+	struct value *next_param = &args[remaining];
 
 	/* Check for %%; print as literal and don't consume a parameter */
 	if (!strncmp(next_start,"%%",2)) {
@@ -1299,7 +1306,10 @@ f_sprintf(union argument *arg)
 
     /* Free any strings from parameters we have now used */
     for (i=0; i<nargs; i++)
-	gpfree_string(&a[i]);
+	gpfree_string(&args[i]);
+
+    if (args != a)
+	free(args);
 }
 
 /* EAM July 2004 - Gnuplot's own string formatting conventions.
@@ -1348,6 +1358,85 @@ f_gprintf(union argument *arg)
 }
 
 
+/* Output time given in seconds from year 2000 into string */
+void
+f_strftime(union argument *arg)
+{
+    struct value fmt, val;
+    char *fmtstr, *buffer;
+    int fmtlen, buflen, length;
+
+    (void) arg; /* Avoid compiler warnings */
+
+    /* Retrieve parameters from top of stack */
+    pop(&val);
+    pop(&fmt);
+    if ( fmt.type != STRING )
+	int_error(NO_CARET,
+		  "First parameter to strftime must be a format string");
+
+    /* Prepare format string.
+     * Make sure the resulting string not empty by adding a space.
+     * Otherwise, the return value of gstrftime doesn't give enough
+     * information.
+     */
+    fmtlen = strlen(fmt.v.string_val) + 1;
+    fmtstr = gp_alloc(fmtlen + 1, "f_strftime: fmt");
+    strncpy(fmtstr, fmt.v.string_val, fmtlen);
+    strncat(fmtstr, " ", fmtlen);
+    buflen = 80 + 2*fmtlen;
+    buffer = gp_alloc(buflen, "f_strftime: buffer");
+
+    /* Get time_str */
+    length = gstrftime(buffer, buflen, fmtstr, real(&val));
+    if (length == 0 || length >= buflen)
+	int_error(NO_CARET, "Resulting string is too long");
+
+    /* Remove trailing space */
+    assert(buffer[length-1] == ' ');
+    buffer[length-1] = NUL;
+
+    gpfree_string(&val);
+    gpfree_string(&fmt);
+    free(fmtstr);
+
+    push(Gstring(&val, buffer));
+    free(buffer);
+}
+
+/* Convert string into seconds from year 2000 */
+void
+f_strptime(union argument *arg)
+{
+    struct value fmt, val;
+    struct tm time_tm;
+    double result;
+
+    (void) arg; /* Avoid compiler warnings */
+
+    pop(&val);
+    pop(&fmt);
+
+    if ( fmt.type != STRING || val.type != STRING )
+	int_error(NO_CARET,
+		  "Both parameters to strptime must be strings");
+    if ( !fmt.v.string_val || !val.v.string_val )
+	int_error(NO_CARET, "Internal error: string not allocated");
+
+
+    /* string -> time_tm */
+    gstrptime(val.v.string_val, fmt.v.string_val, &time_tm);
+
+    /* time_tm -> result */
+    result = gtimegm(&time_tm);
+    FPRINTF((stderr," strptime result = %g seconds \n", result));
+
+    gpfree_string(&val);
+    gpfree_string(&fmt);
+    push(Gcomplex(&val, result, 0.0));
+}
+
+
 /* Return which argument type sprintf will need for this format string:
  *   char*       STRING
  *   int         INTGR
