@@ -1,5 +1,5 @@
 #ifndef lint
-static char *RCSid() { return RCSid("$Id: pm3d.c,v 1.66.2.2 2008/01/11 04:48:09 sfeam Exp $"); }
+static char *RCSid() { return RCSid("$Id: pm3d.c,v 1.66.2.6 2009/06/19 00:01:00 sfeam Exp $"); }
 #endif
 
 /* GNUPLOT - pm3d.c */
@@ -65,7 +65,6 @@ static quadrangle* quadrangles = (quadrangle*)0;
 
 /* Internal prototypes for this module */
 static TBOOLEAN plot_has_palette;
-static TBOOLEAN plot_wants_colorbox;
 static double geomean4 __PROTO((double, double, double, double));
 static double median4 __PROTO((double, double, double, double));
 static void pm3d_plot __PROTO((struct surface_points *, int));
@@ -475,7 +474,8 @@ pm3d_plot(struct surface_points *this_plot, int at_which_z)
 		allocated_quadrangles += GPMAX(scanA->p_count, scanB->p_count) - 1;
 	    }
 	}
-
+	allocated_quadrangles *= (pm3d.interp_i > 1) ? pm3d.interp_i : 1;
+	allocated_quadrangles *= (pm3d.interp_j > 1) ? pm3d.interp_j : 1;
 	quadrangles = (quadrangle*)gp_realloc(quadrangles, allocated_quadrangles * sizeof (quadrangle), "pm3d_plot->quadrangles");
 	/* DEBUG: fprintf(stderr, "allocated_quadrangles = %d\n", allocated_quadrangles); */
     }
@@ -606,10 +606,15 @@ pm3d_plot(struct surface_points *this_plot, int at_which_z)
 		    pointsB[ii].type == OUTRANGE && pointsB[ii1].type == OUTRANGE)
 		    continue;
 	    }
+
+	    if ((pm3d.interp_i <= 1 && pm3d.interp_j <= 1) || pm3d.direction == PM3D_DEPTH) {
 #ifdef EXTENDED_COLOR_SPECS
-	    if (!supply_extended_color_specs) {
+	      if (!supply_extended_color_specs) {
 #endif
-		/* get the gray as the average of the corner z positions (note: log already in)
+		/* Get the gray as the average of the corner z- or gray-positions
+		   (note: log scale is already included). The average is calculated here
+		   if there is no interpolation (including the "pm3d depthorder" option),
+		   otherwise it is done for each interpolated quadrangle later.
 		   I always wonder what is faster: d*0.25 or d/4? Someone knows? -- 0.25 (joze) */
 		if (color_from_column) {
 		    /* color is set in plot3d.c:get_3ddata() */
@@ -646,10 +651,13 @@ pm3d_plot(struct surface_points *this_plot, int at_which_z)
 		       pointsB[ii1].x, pointsB[ii1].y, pointsA[i1].x, pointsA[i1].y);
 #endif
 		/* set the color */
-		set_color(gray);
+		if (pm3d.direction != PM3D_DEPTH)
+		    set_color(gray);
 #ifdef EXTENDED_COLOR_SPECS
-	    }
+	      }
 #endif
+	    }
+
 	    corners[0].x = pointsA[i].x;
 	    corners[0].y = pointsA[i].y;
 	    corners[1].x = pointsB[ii].x;
@@ -667,6 +675,12 @@ pm3d_plot(struct surface_points *this_plot, int at_which_z)
 		corners[1].z = pointsB[ii].z;
 		corners[2].z = pointsB[ii1].z;
 		corners[3].z = pointsA[i1].z;
+		if (color_from_column) {
+		    corners[0].c = pointsA[i].CRD_COLOR;
+		    corners[1].c = pointsB[ii].CRD_COLOR;
+		    corners[2].c = pointsB[ii1].CRD_COLOR;
+		    corners[3].c = pointsA[i1].CRD_COLOR;
+		}
 	    }
 #ifdef EXTENDED_COLOR_SPECS
 	    if (supply_extended_color_specs) {
@@ -688,7 +702,6 @@ pm3d_plot(struct surface_points *this_plot, int at_which_z)
 		}
 	    }
 	    if (pm3d.direction == PM3D_DEPTH) {
-
 		/* copy quadrangle */
 		quadrangle* qp = quadrangles + current_quadrangle;
 		memcpy(qp->corners, corners, 4 * sizeof (gpdPoint));
@@ -700,17 +713,8 @@ pm3d_plot(struct surface_points *this_plot, int at_which_z)
 		current_quadrangle++;
 
 	    } else
-	    filled_quadrangle(corners, icorners);
+    		filled_quadrangle(corners, icorners);
 #else
-	    if (pm3d.direction == PM3D_DEPTH) {
-
-		/* copy quadrangle */
-		quadrangle* qp = quadrangles + current_quadrangle;
-		memcpy(qp->corners, corners, 4 * sizeof (gpdPoint));
-		qp->gray = gray;
-		current_quadrangle++;
-
-	    } else
 	    if (pm3d.interp_i > 1 || pm3d.interp_j > 1) {
 		/* Interpolation is enabled.
 		 * interp_i is the # of points along scan lines
@@ -731,6 +735,12 @@ pm3d_plot(struct surface_points *this_plot, int at_which_z)
 			((corners[3].z - corners[0].z) / pm3d.interp_i) * i1 + corners[0].z;
 		    bl_point[i1][pm3d.interp_j].z =
 			((corners[2].z - corners[1].z) / pm3d.interp_i) * i1 + corners[1].z;
+		    if (color_from_column) {
+			bl_point[i1][0].c =
+			    ((corners[3].c - corners[0].c) / pm3d.interp_i) * i1 + corners[0].c;
+			bl_point[i1][pm3d.interp_j].c =
+			    ((corners[2].c - corners[1].c) / pm3d.interp_i) * i1 + corners[1].c;
+		    }
 		    /* Next we sample j points between each of the new points
 		     * created in the previous step (this samples between
 		     * scan lines) in the same manner. */
@@ -744,6 +754,10 @@ pm3d_plot(struct surface_points *this_plot, int at_which_z)
 			bl_point[i1][j1].z =
 			    ((bl_point[i1][pm3d.interp_j].z - bl_point[i1][0].z) / pm3d.interp_j) *
 				j1 + bl_point[i1][0].z;
+			if (color_from_column)
+			    bl_point[i1][j1].c =
+				((bl_point[i1][pm3d.interp_j].c - bl_point[i1][0].c) / pm3d.interp_j) *
+				    j1 + bl_point[i1][0].c;
 		    }
 		}
 		/* Once all points are created, move them into an appropriate
@@ -763,6 +777,12 @@ pm3d_plot(struct surface_points *this_plot, int at_which_z)
 			corners[3].x = bl_point[i1][j1+1].x;
 			corners[3].y = bl_point[i1][j1+1].y;
 			corners[3].z = bl_point[i1][j1+1].z;
+ 			if (color_from_column) {
+ 			    corners[0].c = bl_point[i1][j1].c;
+ 			    corners[1].c = bl_point[i1+1][j1].c;
+ 			    corners[2].c = bl_point[i1+1][j1+1].c;
+ 			    corners[3].c = bl_point[i1][j1+1].c;
+ 			}
 #if 0
 			printf("(%g,%g),(%g,%g),(%g,%g),(%g,%g)\n",
 			    corners[0].x, corners[0].y,
@@ -776,6 +796,11 @@ pm3d_plot(struct surface_points *this_plot, int at_which_z)
 			    cb2 = z2cb(corners[1].z);
 			    cb3 = z2cb(corners[2].z);
 			    cb4 = z2cb(corners[3].z);
+			} else {
+			    cb1 = corners[0].c;
+			    cb2 = corners[1].c;
+			    cb3 = corners[2].c;
+			    cb4 = corners[3].c;
 			}
 			switch (pm3d.which_corner_color) {
 			    case PM3D_WHICHCORNER_MEAN: avgC = (cb1 + cb2 + cb3 + cb4) * 0.25; break;
@@ -791,12 +816,28 @@ pm3d_plot(struct surface_points *this_plot, int at_which_z)
 			}
 			/* transform z value to gray, i.e. to interval [0,1] */
 			gray = cb2gray(avgC);
-			set_color(gray);
-			filled_quadrangle(corners);
+			if (pm3d.direction != PM3D_DEPTH) {
+			    set_color(gray);
+			    filled_quadrangle(corners);
+			} else {
+			    /* copy quadrangle */
+			    quadrangle* qp = quadrangles + current_quadrangle;
+			    memcpy(qp->corners, corners, 4 * sizeof (gpdPoint));
+			    qp->gray = gray;
+			    current_quadrangle++;
+			}
 		    }
 		}
-	    } else {
-		filled_quadrangle(corners);
+	    } else { /* thus (pm3d.interp_i == 1 && pm3d.interp_j == 1) */
+		if (pm3d.direction != PM3D_DEPTH) {
+		    filled_quadrangle(corners);
+		} else {
+		    /* copy quadrangle */
+		    quadrangle* qp = quadrangles + current_quadrangle;
+		    memcpy(qp->corners, corners, 4 * sizeof (gpdPoint));
+		    qp->gray = gray;
+		    current_quadrangle++;
+		}
 	    } /* interpolate between points */
 #endif
 	} /* loop quadrangles over points of two subsequent scans */
@@ -899,7 +940,7 @@ pm3d_draw_one(struct surface_points *plot)
     }
 
     /* for pm3dCompress.awk */
-    if (gppsfile)
+    if (gppsfile && (pm3d.direction != PM3D_DEPTH))
 	fputs("%pm3d_map_begin\n", gppsfile);
 
     for (; where[i]; i++) {
@@ -921,7 +962,7 @@ pm3d_draw_one(struct surface_points *plot)
     }
 
     /* for pm3dCompress.awk */
-    if (gppsfile)
+    if (gppsfile && (pm3d.direction != PM3D_DEPTH))
 	fputs("%pm3d_map_end\n", gppsfile);
 }
 
@@ -978,10 +1019,8 @@ set_plot_with_palette(int plot_num, int plot_mode)
     struct curve_points *this_2dplot = first_plot;
     int surface = 0;
     struct text_label *this_label = first_label;
-    TBOOLEAN want_palette_but_not_colorbox = FALSE;
 
     plot_has_palette = TRUE;
-    plot_wants_colorbox = TRUE;
     /* Is pm3d switched on globally? */
     if (pm3d.implicit == PM3D_IMPLICIT)
 	return;
@@ -993,18 +1032,12 @@ set_plot_with_palette(int plot_num, int plot_mode)
 	    if (this_2dplot->plot_style == IMAGE)
 		return;
 #endif
-	    if (this_2dplot->lp_properties.use_palette) {
-		if (this_2dplot->lp_properties.pm3d_color.type <= TC_RGB)
-		    want_palette_but_not_colorbox = TRUE;
-		    /* don't return yet -- decide later whether showing color box is desirable */
-		else
-		    return;
-	    }
-#ifdef EAM_DATASTRINGS
-	    if (this_2dplot->labels &&
-		this_2dplot->labels->textcolor.type >= TC_CB)
+	    if (this_2dplot->lp_properties.use_palette
+	    &&  this_2dplot->lp_properties.pm3d_color.type > TC_RGB)
+		return;
+	    if (this_2dplot->labels
+	    &&  this_2dplot->labels->textcolor.type >= TC_CB)
 		return;
-#endif
 	    this_2dplot = this_2dplot->next;
 	}
     }
@@ -1022,8 +1055,8 @@ set_plot_with_palette(int plot_num, int plot_mode)
 	    if (this_3dplot->lp_properties.use_palette) {
 	        int type = this_3dplot->lp_properties.pm3d_color.type;
 		if (type == TC_LT || type == TC_LINESTYLE || type == TC_RGB)
-		    want_palette_but_not_colorbox = TRUE;
-		    /* don't return yet -- decide later whether showing color box is desirable */
+		    /* don't return yet */
+		    ;
 		else
 		    /* TC_DEFAULT: splot x with line|lp|dot palette */
 		    return;
@@ -1055,9 +1088,7 @@ set_plot_with_palette(int plot_num, int plot_mode)
 #undef TC_USES_PALETTE
 
     /* Palette with continuous colors is not used. */
-    if (want_palette_but_not_colorbox == FALSE)
-	plot_has_palette = FALSE; /* otherwise it stays TRUE */
-    plot_wants_colorbox = FALSE;
+    plot_has_palette = FALSE; /* otherwise it stays TRUE */
 }
 
 TBOOLEAN
@@ -1069,6 +1100,6 @@ is_plot_with_palette()
 TBOOLEAN
 is_plot_with_colorbox()
 {
-    return plot_wants_colorbox;
+    return plot_has_palette && (color_box.where != SMCOLOR_BOX_NO);
 }
 
