@@ -1,5 +1,5 @@
 #ifndef lint
-static char *RCSid() { return RCSid("$Id: save.c,v 1.132.2.4 2007/06/18 01:33:56 sfeam Exp $"); }
+static char *RCSid() { return RCSid("$Id: save.c,v 1.132.2.14 2009/07/16 15:52:26 sfeam Exp $"); }
 #endif
 
 /* GNUPLOT - save.c */
@@ -281,6 +281,10 @@ set y2data%s\n",
     fprintf(fp, "set angles %s\n",
 	    (ang2rad == 1.0) ? "radians" : "degrees");
 
+    /* Grid back/front controls tics also. Make sure it is saved */
+    if (grid_layer >= 0)
+	fprintf(fp,"set tics %s\n", grid_layer == 0 ? "back" : "front");
+    
     if (! some_grid_selected())
 	fputs("unset grid\n", fp);
     else {
@@ -545,9 +549,12 @@ set encoding %s\n\
     fputs("set view ", fp);
     if (splot_map == TRUE)
 	fputs("map", fp);
-    else
+    else {
 	fprintf(fp, "%g, %g, %g, %g",
 	    surface_rot_x, surface_rot_z, surface_scale, surface_zscale);
+    }
+    fprintf(fp, "  %s", aspect_ratio_3D == 2 ? "equal xy" :
+			aspect_ratio_3D == 3 ? "equal xyz": "");
 
     fprintf(fp, "\n\
 set samples %d, %d\n\
@@ -753,9 +760,15 @@ set origin %g,%g\n",
 #undef SAVE_AXISLABEL_OR_TITLE
 
     fprintf(fp, "set zero %g\n", zero);
-    fprintf(fp, "set lmargin %g\nset bmargin %g\n"
-	    "set rmargin %g\nset tmargin %g\n",
-	    lmargin, bmargin, rmargin, tmargin);
+
+    fprintf(fp, "set lmargin %s %g\n",
+	    lmargin.scalex == screen ? "at screen" : "", lmargin.x);
+    fprintf(fp, "set bmargin %s %g\n",
+	    bmargin.scalex == screen ? "at screen" : "", bmargin.x);
+    fprintf(fp, "set rmargin %s %g\n",
+	    rmargin.scalex == screen ? "at screen" : "", rmargin.x);
+    fprintf(fp, "set tmargin %s %g\n",
+	    tmargin.scalex == screen ? "at screen" : "", tmargin.x);
 
     fprintf(fp, "set locale \"%s\"\n", get_locale());
 
@@ -798,8 +811,9 @@ set origin %g,%g\n",
     /*
      *  Save palette information
      */
+
     fprintf( fp, "set palette %s %s maxcolors %d ",
-	     sm_palette.positive ? "positive" : "negative",
+	     sm_palette.positive==SMPAL_POSITIVE ? "positive" : "negative",
 	     sm_palette.ps_allcF ? "ps_allcF" : "nops_allcF",
 	sm_palette.use_maxcolors);
     fprintf( fp, "gamma %g ", sm_palette.gamma );
@@ -858,7 +872,7 @@ set origin %g,%g\n",
     save_position(fp, &color_box.origin, FALSE);
     fputs(" size ", fp);
     save_position(fp, &color_box.size, FALSE);
-    fputs(" ", fp);
+    fprintf(fp, " %s ", color_box.layer ==  LAYER_FRONT ? "front" : "back");
     if (color_box.border == 0) fputs("noborder", fp);
 	else if (color_box.border_lt_tag < 0) fputs("bdefault", fp);
 		 else fprintf(fp, "border %d", color_box.border_lt_tag);
@@ -948,6 +962,8 @@ save_tics(FILE *fp, AXIS_INDEX axis)
 	break;
     }
 
+    fprintf(fp, (axis_array[axis].ticdef.rangelimited)?" rangelimit":" norangelimit");
+
     if (axis_array[axis].ticdef.font && *axis_array[axis].ticdef.font)
         fprintf(fp, " font \"%s\"", axis_array[axis].ticdef.font);
 
@@ -962,6 +978,8 @@ save_tics(FILE *fp, AXIS_INDEX axis)
 		(axis_array[axis].ticdef.type == TIC_USER) ? "" : "add");
 	fputs(" (", fp);
 	for (t = axis_array[axis].ticdef.def.user; t != NULL; t = t->next) {
+	    if (t->level < 0)	/* Don't save ticlabels read from data file */
+		continue;
 	    if (t->label)
 		fprintf(fp, "\"%s\" ", conv_text(t->label));
 	    SAVE_NUM_OR_TIME(fp, (double) t->position, axis);
